@@ -24,7 +24,8 @@ class SharePointSite(object):
         if soapaction:
             request.add_header('Soapaction', soapaction)
         response = self.opener.open(request)
-        return etree.parse(response).xpath('/soap:Envelope/soap:Body/*', namespaces=namespaces)[0]
+        r = etree.parse(response).xpath('/soap:Envelope/soap:Body/*', namespaces=namespaces)[0]
+        return r
 
     @property
     def lists(self):
